pynrc.multiaccum
================

.. currentmodule:: pynrc

.. autoclass:: multiaccum
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~multiaccum.__init__
      ~multiaccum.to_dict
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~multiaccum.nd1
      ~multiaccum.nd2
      ~multiaccum.nd3
      ~multiaccum.nf
      ~multiaccum.ngroup
      ~multiaccum.nint
      ~multiaccum.nr1
      ~multiaccum.nr2
      ~multiaccum.nread_tot
      ~multiaccum.patterns_list
      ~multiaccum.read_mode
   
   